API reference
=============


.. contents::
   :local:

.. toctree::

   noctiluca.analysis
   noctiluca.io
   noctiluca.util


noctiluca.parallel
------------------

.. automodule:: noctiluca.parallel
   :members:
   :undoc-members:
   :show-inheritance:

noctiluca.plot
--------------

.. automodule:: noctiluca.plot
   :members:
   :undoc-members:
   :show-inheritance:

noctiluca.taggedset
-------------------

.. automodule:: noctiluca.taggedset
   :members:
   :undoc-members:
   :show-inheritance:

noctiluca.trajectory
--------------------

.. automodule:: noctiluca.trajectory
   :members:
   :undoc-members:
   :show-inheritance:


